# -*- coding: utf-8 -*-
"""
    openclip/constants.py
    =======================================

    provides module constants used for various reusable needs

    these constants take their value from the calling program environment
    (if available), and default to the the expected values.

    > Eg. if bash environment variable OPENCLIP_EXT is set it will be used
    by python scripts running in that environment (if not set programmatically)
"""
import os
import inspect
import sys
import errno
from . import LOG
from .internal import _MODULE_PATH


try:
    OPENCLIP_VERSION = '3'
    """defines default OpenClip XML Version"""

    OPENCLIP_EXT = '.clip'
    """defines default OpenClip file extension"""

    TEST_CLIP_PATH = os.environ.get('OPENCLIP_TEST_CLIP_PATH', os.path.join(_MODULE_PATH,'data','test.clip'))
    """defines path to test openclip xml file"""

    OPENCLIP_VERSION_FORMAT = os.environ.get('OPENCLIP_VERSION_FORMAT', 'v{:0>3d}')
    """defines default version format string with zero-padding of 3 Eg. `v003` for version `3`"""

    OPENCLIP_PATH = os.environ.get('OPENCLIP_PATH', _MODULE_PATH)
    """defines the module's path attribute for convenience"""

    OPENCLIP_MIN_FRAME_PAD = os.environ.get('OPENCLIP_MIN_FRAME_PAD', 4)
    """defines default frame number padding Eg. `frame.0001.dpx`"""
    OPENCLIP_DEVEL = True if os.environ.get('OPENCLIP_DEVEL', False) in ['1', 'true', 'True'] else False
    """defines `DEVEL` state for more verbose logging
    ie. If you want more debugging set the `OPENCLIP_DEVEL` environment variable"""

    LOG.debug(u'OPENCLIP_DEVEL attribute is {0}'.format(OPENCLIP_DEVEL) )

except ValueError, e:
    LOG.error(errno.EINVAL, e.message)

